@@ -11,7 +11,7 @@
 #' @keywords internal
 #' @noRd
 .conj_exponential_sv <- function(s1 = NULL, priors = NULL,
-                                 plot = FALSE, support = NULL, cred.int.level = NULL,
+                                 support = NULL, cred.int.level = NULL,
                                  calculatingSupport = FALSE) {
   out <- list()
   #* `make default prior if none provided`
@@ -45,13 +45,14 @@
     "a" = a_prime,
     "b" = b_prime
   )
+  out$prior <- priors
   #* `save s1 data for plotting`
-  if (plot) {
-    out$plot_df <- data.frame(
-      "range" = support,
-      "prob" = pdf1,
-      "sample" = rep("Sample 1", length(support))
-    )
-  }
+  out$plot_list <- list(
+    "range" = range(support),
+    "ddist_fun" = "stats::dgamma",
+    "priors" = list("shape" = priors$a[1],  "rate" = priors$b[1]),
+    "parameters" = list("shape" = a_prime,
+                        "rate" = b_prime)
+  )
   return(out)
 }
