@@ -3,7 +3,8 @@
 #' @description growthSim can be used to help pick reasonable parameters for common
 #'  growth models to use in prior distributions or to simulate data for example models/plots.
 #'
-#' @param model One of "logistic", "gompertz", "weibull", "frechet", "gumbel", "monomolecular",
+#' @param model One of "logistic", "logistic4", "logistic5", "gompertz",
+#' "weibull", "frechet", "gumbel", "monomolecular",
 #' "exponential", "linear", "power law", "logarithmic", "bragg",
 #' "double logistic", or "double gompertz".
 #' Alternatively this can be a pseudo formula to generate data from a segmented growth curve by
@@ -22,6 +23,8 @@
 #' Changepoints should be specified as "changePointX" or "fixedChangePointX" as in
 #' \code{\link{growthSS}}.
 #' @param D If decay is being simulated then this is the starting point for decay. This defaults to 0.
+#' @param returnParams Logical, should exact parameter values making each line be returned as part of
+#' the data? This may be useful for model evaluation on test data. Defaults to FALSE.
 #'
 #' @return Returns a dataframe of example growth data following the input parameters.
 #'
@@ -38,6 +41,23 @@
 #'   geom_line(aes(color = group)) +
 #'   labs(title = "Logistic")
 #'
+#' simdf <- growthSim("logistic4",
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5), "D" = c(20, 40))
+#' )
+#' ggplot(simdf, aes(time, y, group = interaction(group, id))) +
+#'   geom_line(aes(color = group)) +
+#'   labs(title = "4 Parameter Logistic")
+#'
+#' simdf <- growthSim("logistic5",
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(2, 1.5),
+#'   "D" = c(0, 20), "E" = c(3, 3))
+#' )
+#' ggplot(simdf, aes(time, y, group = interaction(group, id))) +
+#'   geom_line(aes(color = group)) +
+#'   labs(title = "5 Parameter Logistic")
+#'
 #' simdf <- growthSim("gompertz",
 #'   n = 20, t = 25,
 #'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(0.2, 0.25))
@@ -186,8 +206,16 @@
 #'     The \code{params} argument requires some understanding of how each growth model is parameterized.
 #'     Examples of each are below should help, as will the examples.
 #'     \itemize{
-#'     \item \bold{Logistic}: `A / (1 + exp( (B-x)/C) )`
+#'     \item \bold{Logistic}: `A / (1 + exp( (B-x)/C))`
 #'     Where A is the asymptote, B is the inflection point, C is the growth rate.
+#'     \item \bold{Logistic4}: `D + (A - D) / (1 + exp((B - x) / C))`
+#'     Where A is the asymptote (maximum), B is the inflection point, C is the growth rate,
+#'     and D is the lower asymptote (minimum, if this is 0 then the model converges to 3 parameter
+#'     logistic).
+#'     \item \bold{Logistic5}: `D + ((A - D) / (1 + exp((B - x) / C)) ^ E)`
+#'     Where A is the asymptote (maximum), B is the inflection point, C is the growth rate,
+#'     and D is the lower asymptote (minimum), and E is the asymmetry factor (1 is symmetric
+#'     and converges to 4 parameter logistic).
 #'     \item \bold{Gompertz}: `A * exp(-B * exp(-C*x))`
 #'     Where A is the asymptote, B is the inflection point, C is the growth rate.
 #'     \item \bold{Weibull}: `A * (1-exp(-(x/C)^B))`
@@ -241,11 +269,12 @@
 
 growthSim <- function(
     model = c(
-      "logistic", "gompertz", "double logistic", "double gompertz",
-      "monomolecular", "exponential", "linear", "power law", "frechet",
-      "weibull", "gumbel", "logarithmic", "bragg", "lorentz", "beta"
+      "logistic", "logistic4", "logistic5", "gompertz", "double logistic", "double gompertz",
+      "monomolecular", "exponential", "linear", "power law", "frechet", "weibull", "gumbel",
+      "logarithmic", "bragg", "lorentz", "beta"
     ),
-    n = 20, t = 25, params = list(), D = 0) {
+    n = 20, t = 25, params = list(), D = 0,
+    returnParams = FALSE) {
   if (grepl("count:", model)) {
     COUNT <- TRUE
     model <- trimws(gsub("count:", "", model))
@@ -290,9 +319,9 @@ growthSim <- function(
   }
   #* decide which internal funciton to use
   if (!grepl("\\+", model)) {
-    out <- .singleGrowthSim(model, n, t, params, noise, D, int)
+    out <- .singleGrowthSim(model, n, t, params, noise, D, int, returnParams)
   } else {
-    out <- .multiGrowthSim(model, n, t, params, noise, D, int)
+    out <- .multiGrowthSim(model, n, t, params, noise, D, int, returnParams)
   }
   if (COUNT) {
     out <- do.call(rbind, lapply(split(out, interaction(out$group, out$id)), function(sub) {
@@ -308,7 +337,8 @@ growthSim <- function(
 #' @keywords internal
 #' @noRd
 
-.multiGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D = 0, int) {
+.multiGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D = 0, int,
+                            returnParams = FALSE) {
   component_models <- trimws(strsplit(model, "\\+")[[1]])
 
   firstModel <- component_models[1]
@@ -413,12 +443,9 @@ growthSim <- function(
 #' @keywords internal
 #' @noRd
 
-.singleGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D, int) {
-  models <- c(
-    "logistic", "gompertz", "double logistic", "double gompertz",
-    "monomolecular", "exponential", "linear", "power law", "frechet", "weibull", "gumbel",
-    "logarithmic", "bragg", "lorentz", "beta"
-  )
+.singleGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D, int,
+                             returnParams = FALSE) {
+  models <- .available_models()
 
   if (grepl("decay", model)) {
     decay <- TRUE
@@ -428,33 +455,36 @@ growthSim <- function(
   }
 
   matched_model <- match.arg(model, models)
-  gsi <- match.fun(paste0("gsi_", gsub(" ", "", matched_model)))
-
-  if (decay) {
-    gsid <- function(D = 0, ...) {
-      return(D - gsi(...))
-    }
-  } else {
-    gsid <- function(D = 0, ...) {
-      return(0 + gsi(...))
-    }
-  }
+  gsi <- match.fun(paste0(".gsi_", gsub(" ", "", matched_model)))
 
   out <- do.call(rbind, lapply(seq_along(params[[1]]), function(i) {
     pars <- lapply(params, function(p) p[i])
     e_df <- as.data.frame(rbind(do.call(rbind, lapply(1:n, function(e) {
+      gs_res <- gsi(1:t, pars, noise)
+      y <- if (decay) {
+        D - gs_res$y
+      } else {
+        gs_res$y
+      }
       iter_data <- data.frame(
         "id" = paste0("id_", e), "group" = letters[i], "time" = 1:t,
-        "y" = gsid(D = D, 1:t, pars, noise), stringsAsFactors = FALSE
+        "y" = y, stringsAsFactors = FALSE
       )
+      if (returnParams) {
+        iter_data <- cbind(iter_data, gs_res$pars)
+        iter_data <- iter_data[, -which(colnames(iter_data) == "x")]
+      }
       if (int) {
-        iter_data$y <- iter_data$y + rnorm(1, mean = pars[["I"]], sd = noise[["I"]])
+        int_iter <- rnorm(1, mean = pars[["I"]], sd = noise[["I"]])
+        iter_data$y <- iter_data$y + int_iter
+        if (returnParams) {
+          iter_data$I <- int_iter
+        }
       }
       return(iter_data)
     }))))
     return(e_df)
   }))
-
   return(out)
 }
 
@@ -463,100 +493,185 @@ growthSim <- function(
 #* ***** `gsi functions to simulate individual plants` *****
 #* ************************************************************
 
-gsi_logistic <- function(x, pars, noise) {
+#' @keywords internal
+#' @noRd
+.gsi_logistic <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
-  return(a_r / (1 + exp((b_r - x) / c_r)))
+  y <- a_r / (1 + exp((b_r - x) / c_r))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
 }
-gsi_gompertz <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_logistic4 <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
-  return(a_r * exp(-b_r * exp(-c_r * x)))
+  d_r <- pars[["D"]] + rnorm(1, mean = 0, sd = noise[["D"]])
+  y <- d_r + (a_r - d_r) / (1 + exp((b_r - x) / c_r))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "D" = d_r, "x" = x)))
 }
-gsi_doublelogistic <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_logistic5 <- function(x, pars, noise) {
+  a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
+  b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
+  c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
+  d_r <- pars[["D"]] + rnorm(1, mean = 0, sd = noise[["D"]])
+  e_r <- pars[["E"]] + rnorm(1, mean = 0, sd = noise[["E"]])
+  y <- d_r + ((a_r - d_r) / (1 + exp((b_r - x) / c_r)) ^ e_r)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "D" = d_r, "E" = e_r,
+                                           "x" = x)))
+}
+
+#' @keywords internal
+#' @noRd
+.gsi_gompertz <- function(x, pars, noise) {
+  a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
+  b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
+  c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
+  y <- a_r * exp(-b_r * exp(-c_r * x))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
+}
+
+#' @keywords internal
+#' @noRd
+.gsi_doublelogistic <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   a2_r <- pars[["A2"]] + rnorm(1, mean = 0, sd = noise[["A2"]])
   b2_r <- pars[["B2"]] + rnorm(1, mean = 0, sd = noise[["B2"]])
   c2_r <- pars[["C2"]] + rnorm(1, mean = 0, sd = noise[["C2"]])
-  return(a_r / (1 + exp((b_r - x) / c_r)) + ((a2_r - a_r) / (1 + exp((b2_r - x) / c2_r))))
+  y <- a_r / (1 + exp((b_r - x) / c_r)) + ((a2_r - a_r) / (1 + exp((b2_r - x) / c2_r)))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r,
+                                           "A2" = a2_r, "B2" = b2_r, "C2" = c2_r, "x" = x)))
 }
-gsi_doublegompertz <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_doublegompertz <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   a2_r <- pars[["A2"]] + rnorm(1, mean = 0, sd = noise[["A2"]])
   b2_r <- pars[["B2"]] + rnorm(1, mean = 0, sd = noise[["B2"]])
   c2_r <- pars[["C2"]] + rnorm(1, mean = 0, sd = noise[["C2"]])
-  return((a_r * exp(-b_r * exp(-c_r * x))) + ((a2_r - a_r) * exp(-b2_r * exp(-c2_r * (x - b_r)))))
+  y <- (a_r * exp(-b_r * exp(-c_r * x))) + ((a2_r - a_r) * exp(-b2_r * exp(-c2_r * (x - b_r))))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r,
+                                           "A2" = a2_r, "B2" = b2_r, "C2" = c2_r, "x" = x)))
 }
-gsi_monomolecular <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_monomolecular <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
-  return(a_r - a_r * exp(-b_r * x))
+  y <- a_r - a_r * exp(-b_r * x)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "x" = x)))
 }
-gsi_exponential <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_exponential <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
-  return(a_r * exp(b_r * x))
+  y <- a_r * exp(b_r * x)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "x" = x)))
 }
-gsi_linear <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_linear <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
-  return(a_r * x)
+  y <- a_r * x
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "x" = x)))
 }
-gsi_powerlaw <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_powerlaw <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
-  return(a_r * x^(b_r))
+  y <- a_r * x^(b_r)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "x" = x)))
 }
-gsi_logarithmic <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_logarithmic <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
-  return(a_r * log(x))
+  y <- a_r * log(x)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "x" = x)))
 }
-gsi_frechet <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_frechet <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- max(c(0, pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])))
   c_r <- max(c(0, pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])))
   # holding location to 0, b is shape parameter, c is scale (growth rate)
-  return(a_r * exp(-((x - 0) / c_r)^(-b_r)))
+  y <- a_r * exp(-((x - 0) / c_r)^(-b_r))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
 }
-gsi_gumbel <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_gumbel <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   # b is location, c is scale (rate)
-  return(a_r * exp(-exp(-(x - b_r) / c_r)))
+  y <- a_r * exp(-exp(-(x - b_r) / c_r))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
 }
-gsi_weibull <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_weibull <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   # c is scale, b is shape
-  return(a_r * (1 - exp(-(x / c_r)^b_r)))
+  y <- a_r * (1 - exp(-(x / c_r)^b_r))
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
 }
-gsi_bragg <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_bragg <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   # a is max response, b is precision, c is x position of max response
-  return(a_r * exp(-b_r * (x - c_r)^2))
+  y <- a_r * exp(-b_r * (x - c_r)^2)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
 }
-gsi_lorentz <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_lorentz <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   # a is max response, b is precision, c is x position of max response
-  return(a_r / (1 + b_r * (x - c_r)^2))
+  y <- a_r / (1 + b_r * (x - c_r)^2)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "x" = x)))
 }
-gsi_beta <- function(x, pars, noise) {
+
+#' @keywords internal
+#' @noRd
+.gsi_beta <- function(x, pars, noise) {
   a_r <- pars[["A"]] + rnorm(1, mean = 0, sd = noise[["A"]])
   b_r <- pars[["B"]] + rnorm(1, mean = 0, sd = noise[["B"]])
   c_r <- pars[["C"]] + rnorm(1, mean = 0, sd = noise[["C"]])
   d_r <- pars[["D"]] + rnorm(1, mean = 0, sd = noise[["D"]])
   e_r <- pars[["E"]] + rnorm(1, mean = 0, sd = noise[["E"]])
   y <- a_r * (((x - d_r) / (c_r - d_r)) * ((e_r - x) / (e_r - c_r))^((e_r - c_r) / (c_r - d_r)))^b_r
-  return(y)
+  return(list("y" = y, "pars" = data.frame("A" = a_r, "B" = b_r, "C" = c_r, "D" = d_r, "E" = e_r,
+                                           "x" = x)))
 }
