@@ -31,11 +31,7 @@
 .nlrqSS <- function(model, form, tau = 0.5, df, pars = NULL, start = NULL, type = "nlrq", int = FALSE) {
   #* ***** `Define choices and make empty output list`
   out <- list()
-  models <- c(
-    "logistic", "gompertz", "monomolecular", "exponential", "linear", "power law",
-    "double logistic", "double gompertz", "gam", "frechet", "weibull", "gumbel", "logarithmic",
-    "bragg", "lorentz", "beta"
-  )
+  models <- .available_models()
   #* ***** `Make nlrq formula` *****
   #* `parse form argument`
   parsed_form <- .parsePcvrForm(form, df)
@@ -164,6 +160,50 @@
 }
 
 
+#' `4 parameter logistic self starter`
+#' @examples
+#' simdf <- growthSim("logistic4",
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5), "D" = c(5, 20))
+#' )
+#' .initlogistic4(simdf, "time", "y")
+#'
+#' @keywords internal
+#' @noRd
+
+.initlogistic4 <- function(df, x, y, int = FALSE) {
+  obs_min <- min(df[[y]], na.rm = TRUE)
+  if (int) {
+    df[[y]] <- df[[y]] - obs_min
+  }
+  start <- .initlogistic(df, x, y, int = int)
+  start <- stats::setNames(append(start, obs_min), c(names(start), "D"))
+  return(start)
+}
+
+#' `5 parameter logistic self starter`
+#' @examples
+#' simdf <- growthSim("logistic5",
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11),
+#'   "C" = c(3, 3.5), "D" = c(5, 20), "E" = c(1, 1.5))
+#' )
+#' .initlogistic5(simdf, "time", "y")
+#'
+#' @keywords internal
+#' @noRd
+
+.initlogistic5 <- function(df, x, y, int = FALSE) {
+  obs_min <- min(df[[y]], na.rm = TRUE)
+  if (int) {
+    df[[y]] <- df[[y]] - obs_min
+  }
+  start <- .initlogistic(df, x, y, int = int)
+  start <- stats::setNames(append(start, c(obs_min, 1)), c(names(start), "D", "E"))
+  return(start)
+}
+
+
 #' `Goempertz self starter`
 #'
 #' .initgompertz(simdf, "time", "y")
@@ -513,6 +553,64 @@
   return(list("formula" = nf, "pars" = pars))
 }
 
+.nlrq_form_logistic4 <- function(x, y, USEGROUP, group, pars, int = FALSE) {
+  if (int) {
+    total_pars <- c("I", "A", "B", "C", "D")
+  } else {
+    total_pars <- c("A", "B", "C", "D")
+  }
+  if (is.null(pars)) {
+    pars <- total_pars
+  }
+  if (int) {
+    str_nf <- paste0(y, " ~ I[] + D[] + (A[] - D[])/(1+exp((B[]-", x, ")/C[]))")
+  } else {
+    str_nf <- paste0(y, " ~ D[] + (A[] - D[])/(1+exp((B[]-", x, ")/C[]))")
+  }
+  if (USEGROUP) {
+    for (par in total_pars) {
+      if (par %in% pars) {
+        str_nf <- gsub(paste0(par, "\\[\\]"), paste0(par, "[", group, "]"), str_nf)
+      } else {
+        str_nf <- gsub(paste0(par, "\\[\\]"), par, str_nf)
+      }
+    }
+    nf <- as.formula(str_nf)
+  } else {
+    nf <- as.formula(gsub("\\[|\\]", "", str_nf))
+  }
+  return(list("formula" = nf, "pars" = pars))
+}
+
+.nlrq_form_logistic5 <- function(x, y, USEGROUP, group, pars, int = FALSE) {
+  if (int) {
+    total_pars <- c("I", "A", "B", "C", "D", "E")
+  } else {
+    total_pars <- c("A", "B", "C", "D", "E")
+  }
+  if (is.null(pars)) {
+    pars <- total_pars
+  }
+  if (int) {
+    str_nf <- paste0(y, " ~ I[] + D[] + ((A[] - D[])/(1+exp((B[]-", x, ")/C[])) ^ E[])")
+  } else {
+    str_nf <- paste0(y, " ~ D[] + ((A[] - D[])/(1+exp((B[]-", x, ")/C[])) ^ E[])")
+  }
+  if (USEGROUP) {
+    for (par in total_pars) {
+      if (par %in% pars) {
+        str_nf <- gsub(paste0(par, "\\[\\]"), paste0(par, "[", group, "]"), str_nf)
+      } else {
+        str_nf <- gsub(paste0(par, "\\[\\]"), par, str_nf)
+      }
+    }
+    nf <- as.formula(str_nf)
+  } else {
+    nf <- as.formula(gsub("\\[|\\]", "", str_nf))
+  }
+  return(list("formula" = nf, "pars" = pars))
+}
+
 .nlrq_form_gompertz <- function(x, y, USEGROUP, group, pars, int = FALSE) {
   if (int) {
     total_pars <- c("I", "A", "B", "C")
