@@ -45,6 +45,9 @@
 #'   min_bin = 1, max_bin = 180, wide = TRUE
 #' )
 #' pcv.joyplot(x_wide, index = "sim", group = "group")
+#' x_wide$id <- 1
+#' pcv.joyplot(x_wide[grepl("rl?norm_", x_wide$group), ],
+#' index = "sim", y = "group", id = "id", group = "group")
 #' x_long <- mvSim(
 #'   dists = dists, n_samples = 5, counts = 1000,
 #'   min_bin = 1, max_bin = 180, wide = FALSE
@@ -122,6 +125,12 @@ pcv.joyplot <- function(df = NULL, index = NULL, group = NULL, y = NULL, id = NU
     ggplot2::labs(x = index, y = gsub("dummy", "Density", c(y, group)[1])) +
     pcv_theme() +
     ggplot2::theme(legend.position = "none")
+  if (!any(is.na(suppressWarnings(as.numeric(sub$y))))) {
+    p <- p +
+      ggplot2::scale_y_discrete(
+        limits = as.character(sort(as.numeric(sub$y)))
+      )
+  }
   return(p)
 }
 
