@@ -38,6 +38,17 @@ test_that("Fixed Changepoint data can be made by growthSim", {
   expect_equal(any(is.na(as.integer(df$y))), FALSE)
 })
 
+test_that("Fixed Changepoint data can be made by growthSim", {
+  df <- growthSim(
+    model = "int gompertz", n = 5, t = 5,
+    params = list(
+      "I" = 10, "A" = 100, "B" = 10, "C" = 0.25
+    ),
+    returnParams = TRUE
+  )
+  expect_equal(colnames(df), c("id", "group", "time", "y", "A", "B", "C", "I"))
+})
+
 #* ************************************************************
 #* *************** `Logistic growth modeling` ***************
 #* ************************************************************
@@ -145,6 +156,41 @@ test_that("Test Logistic brms model setup", {
   expect_s3_class(ss$formula, "brmsformula")
 })
 
+
+#* ***************************************************************************
+#* *************** `4 and 5 parameter Logistic growth modeling` ***************
+#* ***************************************************************************
+
+set.seed(123)
+logistic4_df <- growthSim("logistic5",
+  n = 20, t = 25,
+  params = list(
+    "A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5),
+    "D" = c(9, 11), "E" = c(0.95, 1.05)
+  )
+)
+
+
+test_that("4 parameter logistic nls model runs", {
+  ss <- suppressMessages(growthSS(
+    model = "logistic4", form = y ~ time | id / group,
+    df = logistic4_df, type = "nls"
+  ))
+  fit <- fitGrowth(ss)
+  expect_s3_class(fit, "nls")
+})
+
+test_that("5 parameter logistic nls model runs", {
+  ss <- suppressMessages(growthSS(
+    model = "logistic5", form = y ~ time | id / group,
+    df = logistic4_df, type = "nls"
+  ))
+  fit <- fitGrowth(ss)
+  expect_s3_class(fit, "nls")
+})
+
+
+
 #* ************************************************************
 #* *************** `Testing pcvrFormula options` ***************
 #* ************************************************************
@@ -535,7 +581,8 @@ test_that("Test survreg", {
   skip_on_cran()
   model <- "survival weibull"
   form <- y > 100 ~ time | id / group
-  df <- growthSim("logistic",
+  df <- growthSim(
+    "logistic",
     n = 20, t = 25,
     params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
   )
@@ -548,6 +595,25 @@ test_that("Test survreg", {
   expect_s3_class(test, "survdiff")
 })
 
+test_that("Test flexsurv", {
+  skip_on_cran()
+  skip_if_not_installed("flexsurv")
+  model <- "survival weibull"
+  form <- y > 100 ~ time | id / group
+  df <- growthSim(
+    "logistic",
+    n = 20, t = 25,
+    params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+  )
+  ss <- growthSS(model = model, form = form, df = df, type = "flexsurv")
+  fit <- fitGrowth(ss)
+  expect_s3_class(fit, "flexsurvreg")
+  p <- growthPlot(fit, form = ss$pcvrForm, df = ss$df)
+  expect_s3_class(p, "ggplot")
+  test <- testGrowth(ss, fit)
+  expect_s3_class(test, "data.frame")
+})
+
 
 #* ************************************************************
 #* *************** `Models with Intercepts` ***************
