@@ -102,6 +102,78 @@ test_that("GrowthSS Helpers for Logistic Data work", {
   expect_type(ss, "list")
 })
 
+test_that("GrowthSS Helpers for 4 Parameter Logistic Data work", {
+  set.seed(123)
+  df <- growthSim("logistic4",
+    n = 20, t = 25,
+    params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5), "D" = c(5, 20))
+  )
+  ss <- suppressMessages(growthSS(
+    model = "logistic4", form = y ~ time | id / group,
+    df = df, type = "nls"
+  ))
+  expect_type(ss, "list")
+  ss <- suppressMessages(growthSS(
+    model = "logistic4", form = y ~ time | id / group,
+    pars = c("A", "B"),
+    df = df, type = "nlrq", tau = c(0.45, 0.55)
+  ))
+  ss <- suppressMessages(growthSS(
+    model = "int_logistic4", form = y ~ time | id / group,
+    df = df[df$group == "a", ], type = "nlrq", tau = c(0.45, 0.55)
+  ))
+  expect_type(ss, "list")
+  ss <- suppressMessages(growthSS(
+    model = "logistic4", form = y ~ time | id / group,
+    df = df[df$group == "a", ], type = "nlme"
+  ))
+  expect_type(ss, "list")
+  ss <- suppressMessages(growthSS(
+    model = "logistic4", form = y ~ time | id / group,
+    start = list("A" = 100, "B" = 10, "C" = 3, "D" = 5),
+    df = df, type = "brms"
+  ))
+  expect_type(ss, "list")
+})
+
+test_that("GrowthSS Helpers for 5 Parameter Logistic Data work", {
+  set.seed(123)
+  df <- growthSim("logistic5",
+    n = 20, t = 25,
+    params = list(
+      "A" = c(200, 160), "B" = c(13, 11),
+      "C" = c(3, 3.5), "D" = c(5, 20),
+      "E" = c(1, 1.5)
+    )
+  )
+  ss <- suppressMessages(growthSS(
+    model = "logistic5", form = y ~ time | id / group,
+    df = df, type = "nls"
+  ))
+  expect_type(ss, "list")
+  ss <- suppressMessages(growthSS(
+    model = "logistic5", form = y ~ time | id / group,
+    pars = c("A", "B"),
+    df = df, type = "nlrq", tau = c(0.45, 0.55)
+  ))
+  ss <- suppressMessages(growthSS(
+    model = "int_logistic5", form = y ~ time | id / group,
+    df = df[df$group == "a", ], type = "nlrq", tau = c(0.45, 0.55)
+  ))
+  expect_type(ss, "list")
+  ss <- suppressMessages(growthSS(
+    model = "logistic5", form = y ~ time | id / group,
+    df = df[df$group == "a", ], type = "nlme"
+  ))
+  expect_type(ss, "list")
+  ss <- suppressMessages(growthSS(
+    model = "logistic5", form = y ~ time | id / group,
+    start = list("A" = 100, "B" = 10, "C" = 3, "D" = 5, "E" = 1),
+    df = df, type = "brms"
+  ))
+  expect_type(ss, "list")
+})
+
 test_that("GrowthSS Helpers for Gompertz Data work", {
   set.seed(123)
   df <- growthSim("gompertz",
@@ -810,6 +882,53 @@ test_that(".logisticChngptForm assembles a formula in all conditions", {
   }
 })
 
+test_that(".logistic4ChngptForm assembles a formula in all conditions", {
+  for (i in seq_len(nrow(conditions))) {
+    prior <- list(
+      "logistic41A" = 1, "logistic41B" = 1, "logistic41C" = 1, "logistic41D" = 1,
+      "c" = 1,
+      "logistic42A" = 1, "logistic42B" = 1, "logistic42C" = 1, "logistic42D" = 1,
+      "c2" = 2,
+      "logistic43A" = 1, "logistic43B" = 1, "logistic43C" = 1, "logistic43D" = 1,
+      "c3" = 3,
+      "logistic44A" = 1, "logistic44B" = 1, "logistic44C" = 1, "logistic44D" = 1
+    )
+    names(prior)[c(4, 8, 12)] <- paste0(conditions[i, "dpar"], c(conditions[i, 3:5]))
+    for (ii in 1:3) {
+      iter <- .logistic4ChngptForm(
+        conditions[i, "x"], position = ii,
+        dpar = conditions[i, "dpar"], priors = prior
+      )
+      expect_equal(names(iter), c("form", "cp", "cpInt", "params"))
+    }
+  }
+})
+
+test_that(".logistic5ChngptForm assembles a formula in all conditions", {
+  for (i in seq_len(nrow(conditions))) {
+    prior <- list(
+      "logistic51A" = 1, "logistic51B" = 1, "logistic51C" = 1, "logistic51D" = 1,
+      "c" = 1,
+      "logistic52A" = 1, "logistic52B" = 1, "logistic52C" = 1, "logistic52D" = 1,
+      "c2" = 2,
+      "logistic53A" = 1, "logistic53B" = 1, "logistic53C" = 1, "logistic53D" = 1,
+      "c3" = 3,
+      "logistic54A" = 1, "logistic54B" = 1, "logistic54C" = 1, "logistic54D" = 1
+    )
+    names(prior)[c(4, 8, 12)] <- paste0(conditions[i, "dpar"], c(conditions[i, 3:5]))
+    for (ii in 1:3) {
+      iter <- .logistic5ChngptForm(
+        conditions[i, "x"],
+        position = ii,
+        dpar = conditions[i, "dpar"],
+        priors = prior
+      )
+      expect_equal(names(iter), c("form", "cp", "cpInt", "params"))
+    }
+  }
+})
+
+
 test_that(".weibullChngptForm assembles a formula in all conditions", {
   for (i in seq_len(nrow(conditions))) {
     prior <- list(
